###########
# Builder #
###########

FROM rust:latest AS builder

RUN rustup target add x86_64-unknown-linux-musl
RUN apt update && apt install -y musl-tools musl-dev
RUN update-ca-certificates

ENV USER=adsbdb
ENV UID=10001

RUN adduser \
    --disabled-password \
    --gecos "" \
    --home "/nonexistent" \
    --shell "/sbin/nologin" \
    --no-create-home \
    --uid "${UID}" \
    "${USER}"


WORKDIR /adsbdb

COPY Cargo.toml Cargo.lock  ./
COPY ./src ./src

RUN cargo build --target x86_64-unknown-linux-musl --release

############
# App only #
############

FROM alpine

# Import from builder.
COPY --from=builder /etc/passwd /etc/passwd
COPY --from=builder /etc/group /etc/group

WORKDIR /adsbdb

# Copy our build
COPY --from=builder /adsbdb/target/x86_64-unknown-linux-musl/release/adsbdb ./

# Use an unprivileged user.
USER adsbdb:adsbdb

CMD ["/adsbdb/adsbdb"]